==> beast-stock-api-1.6.0-20201031.063527-17-sources.jar: com/thebeastshop/stock/vo/SWhCommandSkuVO.java <==
package com.thebeastshop.stock.vo;

import com.thebeastshop.common.BaseDO;

/**
 * Created by libin.kang on 2018/10/18.
 */
public class SWhCommandSkuVO extends BaseDO {
    private Long id;
    private Long commandId;
    private String code;
    private String skuCode;
    private Integer qpb;
    private Integer planedQuantity;
    private Integer quantity;
    private Integer damagedQuantity;
    private Integer specialSkuType;
    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getCommandId() {
        return commandId;
    }

    public void setCommandId(Long commandId) {
        this.commandId = commandId;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getSkuCode() {
        return skuCode;
    }

    public void setSkuCode(String skuCode) {
        this.skuCode = skuCode;
    }

    public Integer getQpb() {
        return qpb;
    }

    public void setQpb(Integer qpb) {
        this.qpb = qpb;
    }

    public Integer getPlanedQuantity() {
        return planedQuantity;
    }

    public void setPlanedQuantity(Integer planedQuantity) {
        this.planedQuantity = planedQuantity;
    }

    public Integer getQuantity() {
        return quantity;
    }

    public void setQuantity(Integer quantity) {
        this.quantity = quantity;
    }

    public Integer getDamagedQuantity() {
        return damagedQuantity;
    }

    public void setDamagedQuantity(Integer damagedQuantity) {
        this.damagedQuantity = damagedQuantity;
    }

    public Integer getSpecialSkuType() {
        return specialSkuType;
    }

    public void setSpecialSkuType(Integer specialSkuType) {
        this.specialSkuType = specialSkuType;
    }
}

==> beast-stock-api-1.7.7-20211125.075512-2-sources.jar: com/thebeastshop/stock/vo/SWhCommandSkuVO.java <==
package com.thebeastshop.stock.vo;

import com.thebeastshop.common.BaseDO;

/**
 * Created by libin.kang on 2018/10/18.
 */
public class SWhCommandSkuVO extends BaseDO {
    private Long id;
    private Long commandId;
    private String code;
    private String skuCode;
    private Integer qpb;
    private Integer planedQuantity;
    private Integer quantity;
    private Integer damagedQuantity;
    private Integer specialSkuType;
    private Integer needHangTag;//是否需要吊牌
    private Integer needGiftBox;//礼品盒类型
    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getCommandId() {
        return commandId;
    }

    public void setCommandId(Long commandId) {
        this.commandId = commandId;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getSkuCode() {
        return skuCode;
    }

    public void setSkuCode(String skuCode) {
        this.skuCode = skuCode;
    }

    public Integer getQpb() {
        return qpb;
    }

    public void setQpb(Integer qpb) {
        this.qpb = qpb;
    }

    public Integer getPlanedQuantity() {
        return planedQuantity;
    }

    public void setPlanedQuantity(Integer planedQuantity) {
        this.planedQuantity = planedQuantity;
    }

    public Integer getQuantity() {
        return quantity;
    }

    public void setQuantity(Integer quantity) {
        this.quantity = quantity;
    }

    public Integer getDamagedQuantity() {
        return damagedQuantity;
    }

    public void setDamagedQuantity(Integer damagedQuantity) {
        this.damagedQuantity = damagedQuantity;
    }

    public Integer getSpecialSkuType() {
        return specialSkuType;
    }

    public void setSpecialSkuType(Integer specialSkuType) {
        this.specialSkuType = specialSkuType;
    }

    public Integer getNeedHangTag() {
        return needHangTag;
    }

    public void setNeedHangTag(Integer needHangTag) {
        this.needHangTag = needHangTag;
    }

    public Integer getNeedGiftBox() {
        return needGiftBox;
    }

    public void setNeedGiftBox(Integer needGiftBox) {
        this.needGiftBox = needGiftBox;
    }
}
